#region Header
/*----------------------------------------------------------------------------------------------------------------------
 * Description : FileDrop Win32 API functions
 
 * File : Win32FileDrop.cs
 * Namespaces : ScipBe.Controls.WinForms
 * Classes : Win32

 * Dates : November 2006 - December 2008
 * Version : 1.1

 * Author : Stefan Cruysberghs
 * Website : http://www.scip.be
------------------------------------------------------------------------------------------------------------------------
Version: MPL 1.1
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/

 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the License.
 
 * The Original Code is ScipBe.Controls.WinForms
 
 * The Initial Developer of the Original Code is Stefan Cruysberghs, http://www.scip.be
 * All Rights Reserved.
------------------------------------------------------------------------------------------------------------------------
History
 * Version 1.0 (November 2006) : First version
------------------------------------------------------------------------------------------------------------------------*/
#endregion

using System;
using System.Runtime.InteropServices;
using System.Text;

namespace ScipBe.Controls.WinForms
{
  partial class Win32
  {
    public const int WM_DROPFILES = 0x0233;

    #region Win32 Shell32.DLL functions
    /// <summary>
    /// Retrieves the names of dropped files that result from a successful drag-and-drop operation
    /// http://windowssdk.msdn.microsoft.com/en-gb/library/ms647250(VS.80).aspx
    /// </summary>
    [DllImport("shell32.dll")]
    public static extern int DragQueryFile(
      IntPtr hDrop, 
      int iFile, 
      StringBuilder fileName, 
      int fileSize
    );

    /// <summary>
    /// Releases memory that the system allocated for use in transferring file names to the application
    /// http://windowssdk.msdn.microsoft.com/en-us/library/ms647249(VS.80).aspx
    /// </summary>
    [DllImport("shell32.dll")]
    public static extern int DragFinish(
      IntPtr hDrop
    );

    /// <summary>
    /// Registers whether a window accepts dropped files
    /// http://windowssdk.msdn.microsoft.com/en-gb/library/ms647248(VS.80).aspx
    /// </summary>
    [DllImport("shell32.dll")]
    public static extern void DragAcceptFiles(
      IntPtr hwnd,
      Boolean fAccept 
    );

    /// <summary>
    /// Retrieves the position of the mouse pointer at the time a file was dropped during a drag-and-drop operation
    /// http://msdn.microsoft.com/library/default.asp?url=/library/en-us/shellcc/platform/shell/reference/functions/dragquerypoint.asp
    /// </summary>
    [DllImport("shell32.dll")]
    public static extern void DragQueryPoint (
      IntPtr hDrop,
      Win32.POINT lppt
    );
    #endregion

    #region Win32 Point Structure
    /// <summary>
    /// Win32 Point Structure
    /// http://msdn.microsoft.com/library/default.asp?url=/library/en-us/vcmfc98/html/_mfc_point_structure.asp
    /// </summary>
    [StructLayout(LayoutKind.Sequential, CharSet = CharSet.Unicode)]
    public class POINT
    {
      public int x = 0;
      public int y = 0;
    }
    #endregion

  }
}
